@@ -48,12 +48,15 @@ patternview_register_final <- function(patternview, target, scheduler) {
   if (identical(patternview$progress, "started")) {
     patternview$progress <- "built"
     scheduler$progress$write_built(target)
+  } else if (identical(patternview$progress, "queued")) {
+    patternview$progress <- "skipped"
+    scheduler$progress$enqueue_skipped(target)
   }
 }
 
 patternview_validate <- function(patternview) {
-  assert_correct_fields(patternview, patternview_new)
-  assert_in(
+  tar_assert_correct_fields(patternview, patternview_new)
+  tar_assert_in(
     patternview$progress,
     c("queued", "started", "built", "canceled", "errored")
   )
