@@ -8,7 +8,7 @@
 #' @param context RStudio API context from
 #'   `rstudioapi::getActiveDocumentContext()`.
 rstudio_addin_tar_target <- function(context = NULL) {
-  assert_package("rstudioapi")
+  tar_assert_package("rstudioapi")
   context <- context %||% rstudioapi::getActiveDocumentContext()
   location <- context$selection[[1L]]$range$start
   rstudioapi::insertText(
